============
Contributors
============

GitHub users, who contributed to Kibitzr in arbitrary order:

* `Igor Sobolev <https://github.com/yigor>`_
* `Delirious Lettuce <https://github.com/delirious-lettuce>`_
* `Martin Virtel <https://github.com/mvtango>`_
